===========
Django Pony
===========

There is no pony in django. Here is a application to add a pony to your
django project.

Installation
============

1. Add "pony" to your pytonpath.
2. Add this line of code somewhere in your template(s)::

    {% include "pony/pony.html" %}

3. That's it! Easy what?

Credits and legal notice
========================

The ascii art pony was made by `Joan Stark`_ and released for free for
**non commercial use**. See his guidlines_ for details.

.. _`Joan Stark`: http://www.ascii-art.com/
.. _guidlines: http://www.geocities.com/SoHo/7373/please.htm
